@@ -1,12 +1,24 @@
 'use strict';
 
-var _ = require('lodash');
-var Boom = require('boom');
-var Promise = require('bluebird');
-var writeFile = Promise.promisify(require('fs').writeFile);
-var unlink = require('fs').unlinkSync;
+function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }
 
-module.exports = Promise.method(function (kbnServer, server, config) {
+var _lodash = require('lodash');
+
+var _lodash2 = _interopRequireDefault(_lodash);
+
+var _boom = require('boom');
+
+var _boom2 = _interopRequireDefault(_boom);
+
+var _bluebird = require('bluebird');
+
+var _bluebird2 = _interopRequireDefault(_bluebird);
+
+var _fs = require('fs');
+
+var writeFile = _bluebird2['default'].promisify(require('fs').writeFile);
+
+module.exports = _bluebird2['default'].method(function (kbnServer, server, config) {
   var path = config.get('pid.file');
   if (!path) return;
 
@@ -22,7 +34,7 @@ module.exports = Promise.method(function (kbnServer, server, config) {
     };
 
     if (config.get('pid.exclusive')) {
-      throw Boom.create(500, _.template(log.tmpl)(log), log);
+      throw _boom2['default'].create(500, _lodash2['default'].template(log.tmpl)(log), log);
     } else {
       server.log(['pid', 'warning'], log);
     }
@@ -36,8 +48,8 @@ module.exports = Promise.method(function (kbnServer, server, config) {
       pid: pid
     });
 
-    var clean = _.once(function (code) {
-      unlink(path);
+    var clean = _lodash2['default'].once(function (code) {
+      (0, _fs.unlinkSync)(path);
     });
 
     process.once('exit', clean); // for "natural" exits
@@ -48,5 +60,9 @@ module.exports = Promise.method(function (kbnServer, server, config) {
       // resend SIGINT
       process.kill(process.pid, 'SIGINT');
     });
+
+    process.on('unhandledRejection', function (reason, promise) {
+      server.log(['warning'], 'Detected an unhandled Promise rejection.\n' + reason);
+    });
   });
 });
