@@ -3,19 +3,19 @@ define(function () {
     // walk up the branch for each parent
     function walk(item, memo) {
       // record the the depth
-      var depth = item.depth - 1;
+      let depth = item.depth - 1;
 
       // Using the aggConfig determine what the field name is. If the aggConfig
       // doesn't exist (which means it's an _all agg) then use the level for
       // the field name
-      var col = item.aggConfig;
-      var field = (col && col.params && col.params.field && col.params.field.displayName)
-        || (col && col.label)
+      const { aggConfig } = item;
+      let field = (aggConfig && aggConfig.getFieldDisplayName())
+        || (aggConfig && aggConfig.label)
         || ('level ' + item.depth);
 
       // Add the row to the tooltipScope.rows
       memo.unshift({
-        aggConfig: col,
+        aggConfig,
         depth: depth,
         field: field,
         bucket: item.name,
