@@ -1,4 +1,4 @@
-var _ = require('lodash');
+import _ from 'lodash';
 
 module.exports = function (chrome, internals) {
   /**
@@ -10,7 +10,7 @@ module.exports = function (chrome, internals) {
    *     determines if the Kibana chrome should be displayed
    */
 
-  var def = true;
+  let def = true;
   internals.setVisibleDefault = (_def) => def = Boolean(_def);
 
   /**
