@@ -1,17 +1,19 @@
-require('babel/polyfill');
+import _ from 'lodash';
+import angular from 'angular';
 
-var _ = require('lodash');
-var $ = require('jquery');
-var angular = require('angular');
+import metadata from 'ui/metadata';
+import 'babel/polyfill';
+import 'ui/timefilter';
+import 'ui/notify';
+import 'ui/private';
+import 'ui/promises';
+import 'ui/storage';
+import 'ui/directives/kbn_src';
+import 'ui/watch_multi';
+import './services';
 
-require('ui/timefilter');
-require('ui/private');
-require('ui/promises');
-
-var metadata = require('ui/metadata');
-
-var chrome = {};
-var internals = _.defaults(
+const chrome = {};
+const internals = _.defaults(
   _.cloneDeep(metadata),
   {
     basePath: '',
@@ -19,23 +21,18 @@ var internals = _.defaults(
     rootTemplate: null,
     showAppsLink: null,
     xsrfToken: null,
+    devMode: true,
     brand: null,
     nav: [],
     applicationClasses: []
   }
 );
 
-$('<link>').attr({
-  href: require('ui/images/elk.ico'),
-  rel: 'shortcut icon'
-}).appendTo('head');
-
 require('./api/apps')(chrome, internals);
 require('./api/xsrf')(chrome, internals);
 require('./api/nav')(chrome, internals);
 require('./api/angular')(chrome, internals);
 require('./api/controls')(chrome, internals);
-require('./api/tabs')(chrome, internals);
 require('./api/template')(chrome, internals);
 require('./api/theme')(chrome, internals);
 
