@@ -2,12 +2,6 @@ import $ from 'jquery';
 
 import chromeNavControlsRegistry from 'ui/registry/chrome_nav_controls';
 import UiModules from 'ui/modules';
-import spinnerHtml from './active_http_spinner.html';
-
-const spinner = {
-  name: 'active http requests',
-  template: spinnerHtml
-};
 
 export default function (chrome, internals) {
 
@@ -19,7 +13,7 @@ export default function (chrome, internals) {
         const parts = [$element.html()];
         const controls = Private(chromeNavControlsRegistry);
 
-        for (const control of [spinner, ...controls.inOrder]) {
+        for (const control of controls.inOrder) {
           parts.unshift(
             `<!-- nav control ${control.name} -->`,
             control.template
